==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/de/d32/settings_8cpp.js <==
var settings_8cpp =
[
    [ "ErrorList", "de/d32/settings_8cpp.html#a3296ce4bae92b253c7643f5402f2b917", null ],
    [ "SettingDescProc", "de/d32/settings_8cpp.html#ae3ec30ce23e5f960f70d8246151cd566", null ],
    [ "SettingDescProcList", "de/d32/settings_8cpp.html#ac682e0fbeb34ca11de093304f6d40c16", null ],
    [ "AILoadConfig", "de/d32/settings_8cpp.html#aa208d615f2c25fdd3bd9d28456042395", null ],
    [ "AISaveConfig", "de/d32/settings_8cpp.html#af030e5abc392019d9f60903ce12b8368", null ],
    [ "ChangeDynamicEngines", "de/d32/settings_8cpp.html#a2a52db6d04106211c77c95848be342bd", null ],
    [ "ChangeMaxHeightLevel", "de/d32/settings_8cpp.html#afc142ffc1cace2447986fd1de192f243", null ],
    [ "Check_PATS", "de/d32/settings_8cpp.html#ab6304df087edaa831746c674ef7a29b1", null ],
    [ "CheckConfig", "de/d32/settings_8cpp.html#abd577ff6da21268ebbef77defe045527", null ],
    [ "CheckFreeformEdges", "de/d32/settings_8cpp.html#a927e7b60fd659f2941074b8c7df9d1db", null ],
    [ "CheckInterval", "de/d32/settings_8cpp.html#aa9df1194800de48732500c509a0be0de", null ],
    [ "CheckRoadSide", "de/d32/settings_8cpp.html#abf568dfdaa27bf5c719a30259e6f2c10", null ],
    [ "CloseSignalGUI", "de/d32/settings_8cpp.html#a2dd67023a4b04d7d1e4edcde708188bf", null ],
    [ "CmdChangeCompanySetting", "de/d32/settings_8cpp.html#acbe5bb0f0c027f8d16d5edc8be03c4e4", null ],
    [ "CmdChangeSetting", "de/d32/settings_8cpp.html#af6f70d5a8a2f80a0ba655cd7d309b776", null ],
    [ "ConvertLandscape", "de/d32/settings_8cpp.html#a91edfe93b27f41336f856d2b857c366f", null ],
    [ "DecodeHexNibble", "de/d32/settings_8cpp.html#a28a282a5ef7c2e8638e2dfa8d769e9c9", null ],
    [ "DecodeHexText", "de/d32/settings_8cpp.html#a0dfda3170346ac9f85574c8cb4b1eb8a", null ],
    [ "DeleteGRFPresetFromConfig", "de/d32/settings_8cpp.html#aa503212f04fca60062c1ab11b5ea9766", null ],
    [ "DeleteSelectStationWindow", "de/d32/settings_8cpp.html#a0219836aba84ed8b6eeb6a63b2ead23d", null ],
    [ "DifficultyNoiseChange", "de/d32/settings_8cpp.html#a3840fe0b18322abf7acc49d16a2fd7d5", null ],
    [ "DragSignalsDensityChanged", "de/d32/settings_8cpp.html#acf02f52322698e2691ded388512d9a3a", null ],
    [ "GameLoadConfig", "de/d32/settings_8cpp.html#a04d10afb17e0dd67d37659f86bc0deb0", null ],
    [ "GameSaveConfig", "de/d32/settings_8cpp.html#a592d18bc1111a44b7f15f3be775e9132", null ],
    [ "GetCompanySettingIndex", "de/d32/settings_8cpp.html#aa1f43c551efdb451986f3f2133b5a3a8", null ],
    [ "GetGRFPresetList", "de/d32/settings_8cpp.html#a13871d14fedcdcc2ded58b5fa7b6f15f", null ],
    [ "GetSettingDescription", "de/d32/settings_8cpp.html#a06278d2bbefb40acb1defbbc119ab109", null ],
    [ "GetSettingFromName", "de/d32/settings_8cpp.html#a6f62e98e5692eb0dc11e76b713ce23aa", null ],
    [ "GRFLoadConfig", "de/d32/settings_8cpp.html#a2bd8aa4d115af37ebbb61388b6d4d543", null ],
    [ "GRFSaveConfig", "de/d32/settings_8cpp.html#a16e5249377a7337ae8346fc63375a211", null ],
    [ "HandleOldDiffCustom", "de/d32/settings_8cpp.html#a8a0970f0444cd5f7d3ba034aa41068a3", null ],
    [ "HandleSettingDescs", "de/d32/settings_8cpp.html#ae89806503cf55f63c12c5bd473624c0a", null ],
    [ "IConsoleGetSetting", "de/d32/settings_8cpp.html#abbcd7a0f9ecd0795a7fd4761a60e8324", null ],
    [ "IConsoleListSettings", "de/d32/settings_8cpp.html#abe98274a6ead02d28de0badbcdb1d037", null ],
    [ "IConsoleSetSetting", "de/d32/settings_8cpp.html#a8ceff0389a976e57310ecaa9240a8816", null ],
    [ "IConsoleSetSetting", "de/d32/settings_8cpp.html#a0afdcfce44ed0539989106d1f41b5565", null ],
    [ "IniLoadConfig", "de/d32/settings_8cpp.html#aa9b7707749d18ae4e304e6bf23a2af60", null ],
    [ "IniLoadSettingList", "de/d32/settings_8cpp.html#aa9882d6b5e7ab81b9b7dabfd23838206", null ],
    [ "IniLoadSettings", "de/d32/settings_8cpp.html#ab61b9ab5329347f07fbc9275579c73fb", null ],
    [ "IniLoadWindowSettings", "de/d32/settings_8cpp.html#ae8818463920e9f3e76844c05238c0655", null ],
    [ "IniSaveSettingList", "de/d32/settings_8cpp.html#a3a4e96c6f3c10efa23fe0e994d207818", null ],
    [ "IniSaveSettings", "de/d32/settings_8cpp.html#a4c4fa976f710eb33ff1921bd6e31b26d", null ],
    [ "IniSaveWindowSettings", "de/d32/settings_8cpp.html#a358ebb53d02501ecda1af3fd71c6a1cb", null ],
    [ "InvalidateAISettingsWindow", "de/d32/settings_8cpp.html#a0c4d1ca2e63623ccca628f7df63f60f8", null ],
    [ "InvalidateBuildIndustryWindow", "de/d32/settings_8cpp.html#aa98dfd9eab68834e7daf8da8f8cc06ef", null ],
    [ "InvalidateCompanyInfrastructureWindow", "de/d32/settings_8cpp.html#a070c25fc84040e755e2cf870741730d0", null ],
    [ "InvalidateCompanyLiveryWindow", "de/d32/settings_8cpp.html#adff0eb4d21bed1159f350615a0bdaf64", null ],
    [ "InvalidateCompanyWindow", "de/d32/settings_8cpp.html#ad14b11d3ed0583d619d02ac872ee9f9f", null ],
    [ "InvalidateDetailsWindow", "de/d32/settings_8cpp.html#aa3059ad8bbbb5db07a41701316c1c5de", null ],
    [ "InvalidateIndustryViewWindow", "de/d32/settings_8cpp.html#a94336d93ff8ff34d90003fa0bda79509", null ],
    [ "InvalidateNewGRFChangeWindows", "de/d32/settings_8cpp.html#a457fc3af8e3f0ea24ee6fb82ff6594b3", null ],
    [ "InvalidateShipPathCache", "de/d32/settings_8cpp.html#a1db5fb913f0b397a4b216ece2c50e601", null ],
    [ "InvalidateTownViewWindow", "de/d32/settings_8cpp.html#aa15ca61c45b0589f3b8ca1b0a9cfffbd", null ],
    [ "InvalidateVehTimetableWindow", "de/d32/settings_8cpp.html#aef1a402675ee63eef6c443eaf8f84b3e", null ],
    [ "IsSignedVarMemType", "de/d32/settings_8cpp.html#afb53bbeb1eb3a0c69d7ead025617248c", null ],
    [ "Load_OPTS", "de/d32/settings_8cpp.html#a54357d37caf93468d96cad0b45d7c085", null ],
    [ "Load_PATS", "de/d32/settings_8cpp.html#afc8af64b88177a75b82626aade771e98", null ],
    [ "LoadFromConfig", "de/d32/settings_8cpp.html#a9bedc3a39f0c464bb7fa3bbc53ea9b87", null ],
    [ "LoadGRFPresetFromConfig", "de/d32/settings_8cpp.html#a1f281a446f7eae8b29c9fa9a5bfd3af0", null ],
    [ "LoadIntList", "de/d32/settings_8cpp.html#a3bdfc9d92985f8347efd292d2b5739f4", null ],
    [ "LoadSettings", "de/d32/settings_8cpp.html#a4439189fb79e5791828f8e14248b7ecb", null ],
    [ "LookupManyOfMany", "de/d32/settings_8cpp.html#a1a4cbad173aa8932da006485a7e1f715", null ],
    [ "LookupOneOfMany", "de/d32/settings_8cpp.html#ab96e9af7926af22d61a07b11119c3b66", null ],
    [ "MakeIntList", "de/d32/settings_8cpp.html#a9eadcca7726d2ab368e5946f861456a7", null ],
    [ "MakeManyOfMany", "de/d32/settings_8cpp.html#a3720d8e933fe7aac1e6973e8c7776a25", null ],
    [ "MakeOneOfMany", "de/d32/settings_8cpp.html#aca62a57770ddafe3218e8d042968b2b4", null ],
    [ "MaxNoAIsChange", "de/d32/settings_8cpp.html#ad23c696b0aa689b7082558e9ffdd4c0f", null ],
    [ "MaxVehiclesChanged", "de/d32/settings_8cpp.html#a51d30350ad864edca92b7ac550060df6", null ],
    [ "ParseIntList", "de/d32/settings_8cpp.html#ad4b146c2f98c2e99714196c794494481", null ],
    [ "PopulationInLabelActive", "de/d32/settings_8cpp.html#aba2a0cecfe420fd8d6e8741ae180db12", null ],
    [ "PrepareOldDiffCustom", "de/d32/settings_8cpp.html#aae2d2008c1cdfeb816754b880f45e816", null ],
    [ "RedrawScreen", "de/d32/settings_8cpp.html#a6a96c1e5b51d6220b716f5f61969dfce", null ],
    [ "RedrawSmallmap", "de/d32/settings_8cpp.html#a43be9a2b1fd1af3b1b0a3cff9dfb4dca", null ],
    [ "RedrawTownAuthority", "de/d32/settings_8cpp.html#a7c47c467e87d336819e3c2412b22750b", null ],
    [ "RoadVehAccelerationModelChanged", "de/d32/settings_8cpp.html#a496846b6462588b226a8a09fcdcde1fa", null ],
    [ "RoadVehSlopeSteepnessChanged", "de/d32/settings_8cpp.html#a57ba184bec7730a1135926d95ec32766", null ],
    [ "Save_PATS", "de/d32/settings_8cpp.html#a1da71b529e76d995917424bec3da402f", null ],
    [ "SaveGRFPresetToConfig", "de/d32/settings_8cpp.html#a3fc0c763e0047df4e153a4fc8c3a1829", null ],
    [ "SaveSettings", "de/d32/settings_8cpp.html#a12c2e369eb39ebeae8ca9221a7f73d91", null ],
    [ "SaveToConfig", "de/d32/settings_8cpp.html#a6994d46231f96c78e4b7e0721c46d7e1", null ],
    [ "SaveVersionInConfig", "de/d32/settings_8cpp.html#afd44cbf11d098d11bb2991c45c5e6eb6", null ],
    [ "SetCompanySetting", "de/d32/settings_8cpp.html#a0a3f2b7a1f15174ceccda2b9d6968755", null ],
    [ "SetDefaultCompanySettings", "de/d32/settings_8cpp.html#a3f942ece39f922bfdb2e907edd357a62", null ],
    [ "SetSettingValue", "de/d32/settings_8cpp.html#ac09860f928a41103e482743404a34f95", null ],
    [ "SetSettingValue", "de/d32/settings_8cpp.html#a56c12e399a3eba27aea4ef6aa30b5d99", null ],
    [ "StationCatchmentChanged", "de/d32/settings_8cpp.html#a7e74e3b98771d1bf8a0725c186b3cfd9", null ],
    [ "StationSpreadChanged", "de/d32/settings_8cpp.html#a9fe06985111e36aee370d1f6f8269e3c", null ],
    [ "StringToVal", "de/d32/settings_8cpp.html#a54370af3e447899964f2a4e9e8e4213f", null ],
    [ "SyncCompanySettings", "de/d32/settings_8cpp.html#a0ff51ab2748d68f36049751f73c54cb5", null ],
    [ "TownFoundingChanged", "de/d32/settings_8cpp.html#afb3b67171e64f45c53a22f7a6507c83a", null ],
    [ "TrainAccelerationModelChanged", "de/d32/settings_8cpp.html#a27129a59e6753e72425e74aa9475d9f0", null ],
    [ "TrainSlopeSteepnessChanged", "de/d32/settings_8cpp.html#a0f8deb05e74cc9ff0d7524173cde8a18", null ],
    [ "UpdateClientConfigValues", "de/d32/settings_8cpp.html#a178fa7e707d82d311af36da51913c6ec", null ],
    [ "UpdateClientName", "de/d32/settings_8cpp.html#a3adb0629c079bf198d9ea1c514eca5ae", null ],
    [ "UpdateConsists", "de/d32/settings_8cpp.html#ac4cc6b6d69389c8a3bc0c2af81b80545", null ],
    [ "UpdateInterval", "de/d32/settings_8cpp.html#ab502321301d38f348eedf6c1a88bb180", null ],
    [ "UpdateIntervalAircraft", "de/d32/settings_8cpp.html#a55da3e7703aced4a8dbf4a84a2052f36", null ],
    [ "UpdateIntervalRoadVeh", "de/d32/settings_8cpp.html#a63d91d8435b7c5d1d293981314551e28", null ],
    [ "UpdateIntervalShips", "de/d32/settings_8cpp.html#a1de46e0c52b1b7d92e7f1ae423a22164", null ],
    [ "UpdateIntervalTrains", "de/d32/settings_8cpp.html#adf9ce6375d8e2043063a1242590d8f49", null ],
    [ "UpdateRconPassword", "de/d32/settings_8cpp.html#a69fdf1251eb9cfe2225fc645e22be319", null ],
    [ "UpdateServerPassword", "de/d32/settings_8cpp.html#a9cfcfa363ef28770e36c88dad0bb2b33", null ],
    [ "v_PositionMainToolbar", "de/d32/settings_8cpp.html#ae211c76817139859d3b3f94f1e865a8c", null ],
    [ "v_PositionStatusbar", "de/d32/settings_8cpp.html#a3968792a8a3bf7a83a3d3d5c918aae73", null ],
    [ "ValidateSettings", "de/d32/settings_8cpp.html#a1a0e5518486136bbfe549b5a1d079ddc", null ],
    [ "Write_ValidateSetting", "de/d32/settings_8cpp.html#a6ea5190c9a66930465ba47e9f80db376", null ],
    [ "ZoomMinMaxChanged", "de/d32/settings_8cpp.html#a6e811066fc96c957b764b06f6e38c116", null ],
    [ "_config_file", "de/d32/settings_8cpp.html#abce6f8400df0d8a8415766218d891970", null ],
    [ "_list_group_names", "de/d32/settings_8cpp.html#ad786780467af850999118d1486303594", null ],
    [ "_old_vds", "de/d32/settings_8cpp.html#a6d3e8b346e8d38db90994b7de1a9657b", null ],
    [ "_setting_chunk_handlers", "de/d32/settings_8cpp.html#a4d2e9ac804d1dc36fda5a1e019811917", null ],
    [ "_settings_client", "de/d32/settings_8cpp.html#af8b5c0dfe0538f80b46f297410e4c676", null ],
    [ "_settings_error_list", "de/d32/settings_8cpp.html#a3638baa7920f0dc4a6eeb96a073fe28d", null ],
    [ "_settings_game", "de/d32/settings_8cpp.html#a8acffe507b271f5b5b32d8a3de5d40aa", null ],
    [ "_settings_newgame", "de/d32/settings_8cpp.html#ab58b9679eca99cca11a46ca10d6c9a7a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/de/d32/settings_8cpp.js <==
var settings_8cpp =
[
    [ "HAS_TRUETYPE_FONT", "de/d32/settings_8cpp.html#acd628cd380b23ed1eca0dd09aabb0034", null ],
    [ "ErrorList", "de/d32/settings_8cpp.html#a3296ce4bae92b253c7643f5402f2b917", null ],
    [ "SettingDescProc", "de/d32/settings_8cpp.html#ae3ec30ce23e5f960f70d8246151cd566", null ],
    [ "SettingDescProcList", "de/d32/settings_8cpp.html#a0087c9dc3d477ee49d3b54617bfb2a8e", null ],
    [ "AILoadConfig", "de/d32/settings_8cpp.html#aa208d615f2c25fdd3bd9d28456042395", null ],
    [ "AISaveConfig", "de/d32/settings_8cpp.html#af030e5abc392019d9f60903ce12b8368", null ],
    [ "ChangeDynamicEngines", "de/d32/settings_8cpp.html#a2a52db6d04106211c77c95848be342bd", null ],
    [ "ChangeMaxHeightLevel", "de/d32/settings_8cpp.html#afc142ffc1cace2447986fd1de192f243", null ],
    [ "Check_PATS", "de/d32/settings_8cpp.html#ab6304df087edaa831746c674ef7a29b1", null ],
    [ "CheckFreeformEdges", "de/d32/settings_8cpp.html#a927e7b60fd659f2941074b8c7df9d1db", null ],
    [ "CheckInterval", "de/d32/settings_8cpp.html#aa9df1194800de48732500c509a0be0de", null ],
    [ "CheckRoadSide", "de/d32/settings_8cpp.html#abf568dfdaa27bf5c719a30259e6f2c10", null ],
    [ "CloseSignalGUI", "de/d32/settings_8cpp.html#a2dd67023a4b04d7d1e4edcde708188bf", null ],
    [ "CmdChangeCompanySetting", "de/d32/settings_8cpp.html#acbe5bb0f0c027f8d16d5edc8be03c4e4", null ],
    [ "CmdChangeSetting", "de/d32/settings_8cpp.html#af6f70d5a8a2f80a0ba655cd7d309b776", null ],
    [ "ConvertLandscape", "de/d32/settings_8cpp.html#a91edfe93b27f41336f856d2b857c366f", null ],
    [ "DecodeHexNibble", "de/d32/settings_8cpp.html#a28a282a5ef7c2e8638e2dfa8d769e9c9", null ],
    [ "DecodeHexText", "de/d32/settings_8cpp.html#aaee7f1c51c80c7d2018b6b262334aebf", null ],
    [ "DeleteGRFPresetFromConfig", "de/d32/settings_8cpp.html#aa503212f04fca60062c1ab11b5ea9766", null ],
    [ "DeleteSelectStationWindow", "de/d32/settings_8cpp.html#a0219836aba84ed8b6eeb6a63b2ead23d", null ],
    [ "DifficultyNoiseChange", "de/d32/settings_8cpp.html#a3840fe0b18322abf7acc49d16a2fd7d5", null ],
    [ "DragSignalsDensityChanged", "de/d32/settings_8cpp.html#acf02f52322698e2691ded388512d9a3a", null ],
    [ "GameLoadConfig", "de/d32/settings_8cpp.html#a04d10afb17e0dd67d37659f86bc0deb0", null ],
    [ "GameSaveConfig", "de/d32/settings_8cpp.html#a592d18bc1111a44b7f15f3be775e9132", null ],
    [ "GetCompanySettingIndex", "de/d32/settings_8cpp.html#aa1f43c551efdb451986f3f2133b5a3a8", null ],
    [ "GetGRFPresetList", "de/d32/settings_8cpp.html#a1788af19bee1a02d1084669cada95fea", null ],
    [ "GetSettingDescription", "de/d32/settings_8cpp.html#a06278d2bbefb40acb1defbbc119ab109", null ],
    [ "GetSettingFromName", "de/d32/settings_8cpp.html#a6f62e98e5692eb0dc11e76b713ce23aa", null ],
    [ "GRFLoadConfig", "de/d32/settings_8cpp.html#a2bd8aa4d115af37ebbb61388b6d4d543", null ],
    [ "GRFSaveConfig", "de/d32/settings_8cpp.html#a16e5249377a7337ae8346fc63375a211", null ],
    [ "HandleOldDiffCustom", "de/d32/settings_8cpp.html#a8a0970f0444cd5f7d3ba034aa41068a3", null ],
    [ "HandleSettingDescs", "de/d32/settings_8cpp.html#ae89806503cf55f63c12c5bd473624c0a", null ],
    [ "IConsoleGetSetting", "de/d32/settings_8cpp.html#abbcd7a0f9ecd0795a7fd4761a60e8324", null ],
    [ "IConsoleListSettings", "de/d32/settings_8cpp.html#abe98274a6ead02d28de0badbcdb1d037", null ],
    [ "IConsoleSetSetting", "de/d32/settings_8cpp.html#a8ceff0389a976e57310ecaa9240a8816", null ],
    [ "IConsoleSetSetting", "de/d32/settings_8cpp.html#a0afdcfce44ed0539989106d1f41b5565", null ],
    [ "IniLoadConfig", "de/d32/settings_8cpp.html#aa9b7707749d18ae4e304e6bf23a2af60", null ],
    [ "IniLoadSettingList", "de/d32/settings_8cpp.html#a9c4a91a2d2c1d52d155e4fca2b40bda1", null ],
    [ "IniLoadSettings", "de/d32/settings_8cpp.html#ab61b9ab5329347f07fbc9275579c73fb", null ],
    [ "IniLoadWindowSettings", "de/d32/settings_8cpp.html#ae8818463920e9f3e76844c05238c0655", null ],
    [ "IniSaveSettingList", "de/d32/settings_8cpp.html#a55d6c72888d48ee5b18c23f9d514da7c", null ],
    [ "IniSaveSettings", "de/d32/settings_8cpp.html#a4c4fa976f710eb33ff1921bd6e31b26d", null ],
    [ "IniSaveWindowSettings", "de/d32/settings_8cpp.html#a358ebb53d02501ecda1af3fd71c6a1cb", null ],
    [ "InvalidateAISettingsWindow", "de/d32/settings_8cpp.html#a0c4d1ca2e63623ccca628f7df63f60f8", null ],
    [ "InvalidateBuildIndustryWindow", "de/d32/settings_8cpp.html#aa98dfd9eab68834e7daf8da8f8cc06ef", null ],
    [ "InvalidateCompanyInfrastructureWindow", "de/d32/settings_8cpp.html#a070c25fc84040e755e2cf870741730d0", null ],
    [ "InvalidateCompanyLiveryWindow", "de/d32/settings_8cpp.html#adff0eb4d21bed1159f350615a0bdaf64", null ],
    [ "InvalidateCompanyWindow", "de/d32/settings_8cpp.html#ad14b11d3ed0583d619d02ac872ee9f9f", null ],
    [ "InvalidateDetailsWindow", "de/d32/settings_8cpp.html#aa3059ad8bbbb5db07a41701316c1c5de", null ],
    [ "InvalidateIndustryViewWindow", "de/d32/settings_8cpp.html#a94336d93ff8ff34d90003fa0bda79509", null ],
    [ "InvalidateNewGRFChangeWindows", "de/d32/settings_8cpp.html#a457fc3af8e3f0ea24ee6fb82ff6594b3", null ],
    [ "InvalidateShipPathCache", "de/d32/settings_8cpp.html#a1db5fb913f0b397a4b216ece2c50e601", null ],
    [ "InvalidateTownViewWindow", "de/d32/settings_8cpp.html#aa15ca61c45b0589f3b8ca1b0a9cfffbd", null ],
    [ "InvalidateVehTimetableWindow", "de/d32/settings_8cpp.html#aef1a402675ee63eef6c443eaf8f84b3e", null ],
    [ "IsSignedVarMemType", "de/d32/settings_8cpp.html#afb53bbeb1eb3a0c69d7ead025617248c", null ],
    [ "Load_OPTS", "de/d32/settings_8cpp.html#a54357d37caf93468d96cad0b45d7c085", null ],
    [ "Load_PATS", "de/d32/settings_8cpp.html#afc8af64b88177a75b82626aade771e98", null ],
    [ "LoadFromConfig", "de/d32/settings_8cpp.html#a9bedc3a39f0c464bb7fa3bbc53ea9b87", null ],
    [ "LoadGRFPresetFromConfig", "de/d32/settings_8cpp.html#a1f281a446f7eae8b29c9fa9a5bfd3af0", null ],
    [ "LoadIntList", "de/d32/settings_8cpp.html#a3bdfc9d92985f8347efd292d2b5739f4", null ],
    [ "LoadSettings", "de/d32/settings_8cpp.html#a4439189fb79e5791828f8e14248b7ecb", null ],
    [ "LookupManyOfMany", "de/d32/settings_8cpp.html#a1a4cbad173aa8932da006485a7e1f715", null ],
    [ "LookupOneOfMany", "de/d32/settings_8cpp.html#ab96e9af7926af22d61a07b11119c3b66", null ],
    [ "MakeIntList", "de/d32/settings_8cpp.html#a9eadcca7726d2ab368e5946f861456a7", null ],
    [ "MakeManyOfMany", "de/d32/settings_8cpp.html#a3720d8e933fe7aac1e6973e8c7776a25", null ],
    [ "MakeOneOfMany", "de/d32/settings_8cpp.html#aca62a57770ddafe3218e8d042968b2b4", null ],
    [ "MaxNoAIsChange", "de/d32/settings_8cpp.html#ad23c696b0aa689b7082558e9ffdd4c0f", null ],
    [ "MaxVehiclesChanged", "de/d32/settings_8cpp.html#a51d30350ad864edca92b7ac550060df6", null ],
    [ "ParseIntList", "de/d32/settings_8cpp.html#a5449039e7f67afd6fc41d1b3fdcee7f2", null ],
    [ "PopulationInLabelActive", "de/d32/settings_8cpp.html#aba2a0cecfe420fd8d6e8741ae180db12", null ],
    [ "PrepareOldDiffCustom", "de/d32/settings_8cpp.html#aae2d2008c1cdfeb816754b880f45e816", null ],
    [ "RedrawScreen", "de/d32/settings_8cpp.html#a6a96c1e5b51d6220b716f5f61969dfce", null ],
    [ "RedrawSmallmap", "de/d32/settings_8cpp.html#a43be9a2b1fd1af3b1b0a3cff9dfb4dca", null ],
    [ "RedrawTownAuthority", "de/d32/settings_8cpp.html#a7c47c467e87d336819e3c2412b22750b", null ],
    [ "RoadVehAccelerationModelChanged", "de/d32/settings_8cpp.html#a496846b6462588b226a8a09fcdcde1fa", null ],
    [ "RoadVehSlopeSteepnessChanged", "de/d32/settings_8cpp.html#a57ba184bec7730a1135926d95ec32766", null ],
    [ "Save_PATS", "de/d32/settings_8cpp.html#a1da71b529e76d995917424bec3da402f", null ],
    [ "SaveGRFPresetToConfig", "de/d32/settings_8cpp.html#a3fc0c763e0047df4e153a4fc8c3a1829", null ],
    [ "SaveSettings", "de/d32/settings_8cpp.html#a12c2e369eb39ebeae8ca9221a7f73d91", null ],
    [ "SaveToConfig", "de/d32/settings_8cpp.html#a6994d46231f96c78e4b7e0721c46d7e1", null ],
    [ "SaveVersionInConfig", "de/d32/settings_8cpp.html#afd44cbf11d098d11bb2991c45c5e6eb6", null ],
    [ "SetCompanySetting", "de/d32/settings_8cpp.html#a0a3f2b7a1f15174ceccda2b9d6968755", null ],
    [ "SetDefaultCompanySettings", "de/d32/settings_8cpp.html#a3f942ece39f922bfdb2e907edd357a62", null ],
    [ "SetSettingValue", "de/d32/settings_8cpp.html#a56c12e399a3eba27aea4ef6aa30b5d99", null ],
    [ "SetSettingValue", "de/d32/settings_8cpp.html#ac09860f928a41103e482743404a34f95", null ],
    [ "StationCatchmentChanged", "de/d32/settings_8cpp.html#a7e74e3b98771d1bf8a0725c186b3cfd9", null ],
    [ "StationSpreadChanged", "de/d32/settings_8cpp.html#a9fe06985111e36aee370d1f6f8269e3c", null ],
    [ "StringToVal", "de/d32/settings_8cpp.html#a54370af3e447899964f2a4e9e8e4213f", null ],
    [ "SyncCompanySettings", "de/d32/settings_8cpp.html#a0ff51ab2748d68f36049751f73c54cb5", null ],
    [ "TownFoundingChanged", "de/d32/settings_8cpp.html#afb3b67171e64f45c53a22f7a6507c83a", null ],
    [ "TrainAccelerationModelChanged", "de/d32/settings_8cpp.html#a27129a59e6753e72425e74aa9475d9f0", null ],
    [ "TrainSlopeSteepnessChanged", "de/d32/settings_8cpp.html#a0f8deb05e74cc9ff0d7524173cde8a18", null ],
    [ "UpdateClientConfigValues", "de/d32/settings_8cpp.html#a178fa7e707d82d311af36da51913c6ec", null ],
    [ "UpdateClientName", "de/d32/settings_8cpp.html#a3adb0629c079bf198d9ea1c514eca5ae", null ],
    [ "UpdateConsists", "de/d32/settings_8cpp.html#ac4cc6b6d69389c8a3bc0c2af81b80545", null ],
    [ "UpdateInterval", "de/d32/settings_8cpp.html#ab502321301d38f348eedf6c1a88bb180", null ],
    [ "UpdateIntervalAircraft", "de/d32/settings_8cpp.html#a55da3e7703aced4a8dbf4a84a2052f36", null ],
    [ "UpdateIntervalRoadVeh", "de/d32/settings_8cpp.html#a63d91d8435b7c5d1d293981314551e28", null ],
    [ "UpdateIntervalShips", "de/d32/settings_8cpp.html#a1de46e0c52b1b7d92e7f1ae423a22164", null ],
    [ "UpdateIntervalTrains", "de/d32/settings_8cpp.html#adf9ce6375d8e2043063a1242590d8f49", null ],
    [ "UpdateRconPassword", "de/d32/settings_8cpp.html#a69fdf1251eb9cfe2225fc645e22be319", null ],
    [ "UpdateServerPassword", "de/d32/settings_8cpp.html#a9cfcfa363ef28770e36c88dad0bb2b33", null ],
    [ "v_PositionMainToolbar", "de/d32/settings_8cpp.html#ae211c76817139859d3b3f94f1e865a8c", null ],
    [ "v_PositionStatusbar", "de/d32/settings_8cpp.html#a3968792a8a3bf7a83a3d3d5c918aae73", null ],
    [ "ValidateSettings", "de/d32/settings_8cpp.html#a1a0e5518486136bbfe549b5a1d079ddc", null ],
    [ "Write_ValidateSetting", "de/d32/settings_8cpp.html#a6ea5190c9a66930465ba47e9f80db376", null ],
    [ "ZoomMinMaxChanged", "de/d32/settings_8cpp.html#a6e811066fc96c957b764b06f6e38c116", null ],
    [ "_config_file", "de/d32/settings_8cpp.html#ad24b90719b1d40843c682f9b7a778f97", null ],
    [ "_list_group_names", "de/d32/settings_8cpp.html#ad786780467af850999118d1486303594", null ],
    [ "_old_vds", "de/d32/settings_8cpp.html#a6d3e8b346e8d38db90994b7de1a9657b", null ],
    [ "_setting_chunk_handlers", "de/d32/settings_8cpp.html#a4d2e9ac804d1dc36fda5a1e019811917", null ],
    [ "_settings_client", "de/d32/settings_8cpp.html#af8b5c0dfe0538f80b46f297410e4c676", null ],
    [ "_settings_error_list", "de/d32/settings_8cpp.html#a3638baa7920f0dc4a6eeb96a073fe28d", null ],
    [ "_settings_game", "de/d32/settings_8cpp.html#a8acffe507b271f5b5b32d8a3de5d40aa", null ],
    [ "_settings_newgame", "de/d32/settings_8cpp.html#ab58b9679eca99cca11a46ca10d6c9a7a", null ]
];
